@@ -3,7 +3,7 @@ use v5.36;
 use strict;
 use warnings;
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use Carp qw(croak);
 use Fcntl qw(F_GETFL F_SETFL O_NONBLOCK F_GETFD F_SETFD FD_CLOEXEC);
@@ -424,6 +424,7 @@ Linux::Event::Listen - Listening sockets for Linux::Event
 
   my $loop = Linux::Event->new;
 
+  # Basic usage: accept sockets and attach your own per-connection watchers.
   my $listen = Linux::Event::Listen->new(
     loop => $loop,
     host => '127.0.0.1',
@@ -431,42 +432,51 @@ Linux::Event::Listen - Listening sockets for Linux::Event
 
     on_accept => sub ($loop, $client_fh, $peer, $listen) {
       # You own $client_fh. It is already non-blocking.
-      # Attach whatever per-connection watchers you want:
       $loop->watch($client_fh,
         read => sub ($loop, $fh, $w) {
           my $buf;
           my $n = sysread($fh, $buf, 8192);
+
           if (!defined $n || $n == 0) {
             $w->cancel;
             close $fh;
             return;
           }
+
           # ... handle $buf ...
         },
       );
     },
 
-    
-# Canonical server pattern (Listen + Stream + line codec):
-#   use Linux::Event::Stream;
-#
-#   on_accept => sub ($loop, $client_fh, $peer, $listen) {
-#     my $stream = Linux::Event::Stream->new(
-#       loop       => $loop,
-#       fh         => $client_fh,
-#       codec      => 'line',   # built-in codec alias in Linux::Event::Stream 0.002+
-#       on_message => sub ($stream, $line, $data) {
-#         # $line is a complete line (without trailing "\n").
-#         $stream->write_message("echo: $line");
-#         $stream->close_after_drain if $line eq 'quit';
-#       },
-#     );
-#   },
-on_error => sub ($loop, $err, $listen) {
+    on_error => sub ($loop, $err, $listen) {
       warn "listener error ($err->{op}): $err->{error}\n";
     },
   );
 
+  # Canonical server pattern: Listen + Stream + line codec.
+  # This keeps Listen focused on accepting sockets while Stream handles buffered
+  # I/O and framing.
+  #
+  #   use Linux::Event::Stream;
+  #
+  #   Linux::Event::Listen->new(
+  #     loop => $loop,
+  #     host => '127.0.0.1',
+  #     port => 3000,
+  #
+  #     on_accept => sub ($loop, $client_fh, $peer, $listen) {
+  #       Linux::Event::Stream->new(
+  #         loop       => $loop,
+  #         fh         => $client_fh,
+  #         codec      => 'line',
+  #         on_message => sub ($stream, $line, $data) {
+  #           $stream->write_message("echo: $line");
+  #           $stream->close_after_drain if $line eq 'quit';
+  #         },
+  #       );
+  #     },
+  #   );
+
   $loop->run;
 
 =head1 DESCRIPTION
@@ -481,6 +491,8 @@ This distribution is intentionally small and policy-light:
 
 =item *
 
+It accepts connections and invokes your callback; it does not implement any
+application protocol.
 
 =item *
 
@@ -706,22 +718,9 @@ The following errors are retried: C<EINTR>, C<ECONNABORTED>.
 
 =head1 NOTES
 
-=head1 SEE ALSO
-
-L<Linux::Event>, L<Linux::Event::Loop>, L<Linux::Event::Watcher>, L<IO::Socket::IP>
-
-=head1 AUTHOR
-
-Joshua S. Day
-
-=head1 LICENSE
-
-Same terms as Perl itself.
-
-=cut
 =head1 STREAM INTEGRATION
 
-L<Linux::Event::Listen> is intentionally policy-light: it accepts connections and
+Linux::Event::Listen is intentionally policy-light: it accepts connections and
 hands you a non-blocking client filehandle. A common pattern is to immediately
 wrap the client socket in L<Linux::Event::Stream> and use a codec to define
 message boundaries. For example, line-delimited protocols:
@@ -739,13 +738,24 @@ message boundaries. For example, line-delimited protocols:
         fh         => $client_fh,
         codec      => 'line',
         on_message => sub ($stream, $line, $data) {
-          $stream->write_message($line);  # echo
+          $stream->write_message("echo: $line");
+          $stream->close_after_drain if $line eq 'quit';
         },
       );
     },
   );
 
-This keeps C<Listen> focused on accepting sockets while C<Stream> handles buffered
-I/O and framing.
+This keeps Listen focused on accepting sockets while Stream handles buffered I/O
+and framing.
 
+=head1 SEE ALSO
 
+L<Linux::Event>, L<Linux::Event::Loop>, L<Linux::Event::Watcher>, L<IO::Socket::IP>
+
+=head1 AUTHOR
+
+Joshua S. Day
+
+=head1 LICENSE
+
+Same terms as Perl itself.
